@@ -11,7 +11,7 @@ library(stringr)
 library(dplyr)
 library(fixedincome)
 
-df <- futures_get(
+df <- futures_mget(
     first_date = "2021-01-01",
     last_date = "2022-04-27",
     by = 5
