@@ -7,8 +7,7 @@ test_df <- function(df_in) {
   return(invisible(TRUE))
 }
 
-test_that("Test of yc function", {
-  
+test_that("Test of yc_mget function", {
   if (!covr::in_covr()) {
     skip_on_cran()
     skip_if_offline()
@@ -18,7 +17,7 @@ test_that("Test of yc function", {
   last_date <- Sys.Date()
 
   # first call (no cache)
-  df_yc_1 <- yc_get(first_date,
+  df_yc_1 <- yc_mget(first_date,
     last_date,
     by = 5,
     do_cache = FALSE
@@ -27,12 +26,33 @@ test_that("Test of yc function", {
   test_df(df_yc_1)
 
   # first call (with cache)
-  df_yc_2 <- yc_get(first_date,
+  df_yc_2 <- yc_mget(first_date,
     last_date,
     by = 5
   )
 
   test_df(df_yc_2)
 
+  expect_identical(df_yc_1, df_yc_2)
+})
+
+test_that("Test of yc_get function", {
+  if (!covr::in_covr()) {
+    skip_on_cran()
+    skip_if_offline()
+  }
+
+  refdate <- bizdays::offset(Sys.Date(), -1, "Brazil/ANBIMA")
+
+  # first call (no cache)
+  df_yc_1 <- yc_get(refdate, do_cache = FALSE)
+
+  test_df(df_yc_1)
+
+  # first call (with cache)
+  df_yc_2 <- yc_get(refdate)
+
+  test_df(df_yc_2)
+
   expect_identical(df_yc_1, df_yc_2)
 })
\ No newline at end of file
